@@ -4,8 +4,8 @@ from .context import (
     ElementNotFound,
     MultipleElementsFound,
     TimeoutException,
-    HAS_RECOGNITION,
 )
 
-from .converter import ConverterKeywords
+from .document import DocumentKeywords
 from .finder import FinderKeywords
+from .model import ModelKeywords
